@@ -103,7 +103,7 @@ class AttrDict(OrderedDict):
 	def update_yaml(self, path):
 		self.update_flat(self.from_yaml(path))
 
-	def clone(self):
+	def clone(self, apply_func=None, items=False):
 		clone = AttrDict()
 		clone.update_dict(self)
 		return clone
@@ -134,6 +134,13 @@ class AttrDict(OrderedDict):
 			else: v = func(v) if not items else func(k, v)
 			if update: self[k] = v
 
+	def _lya__apply_flat(self, func, update=True):
+		flat = self.flatten_dict(self)
+		for n, (k, v) in enumerate(flat):
+			v = func(k, v)
+			if update: flat[n] = k, v
+		if update: self.update_flat(flat)
+
 	def _lya__filter(self, func, items=False):
 		for k,v in self.viewitems():
 			if isinstance(v, AttrDict): v = v._lya__filter(func, items=items)
